<?php

  /*
   * Cette classe decrit un plugin "vide" et peut servir de base
   * au developpement d'un nouveau plugin.
   *
   *
   * pour creer un nouveau plugin (par exemple "mon_plugin") :
   *
   *  - creez un dossier "mon_plugin" dans le dossier "mw/plugins"
   *
   *  - copiez dans ce dossier le fichier "mw_minimal.php" et renommez-le
   *    en "mon_plugin.php"
   *
   *  - dans "mon_plugin.php", renommez la classe en :
   *
   *   class mon_plugin extends mw_plugin
   *
   * vous aurez alors un nouveau plugin, activable dans l'administration
   * du site.
   *
   *
   * Votre dossier de plugin peut contenir des dossiers :
   *
   *  - app/controllers
   *  - app/data
   *  - app/out
   *  - app/observers
   *  - ...
   *
   * ces dossiers seront traites de le meme facon que ceux de
   * l'application principale (dans le dossier mw/app)
   *
   */

  class mw_minimal extends mw_plugin{

    /*
     * retourne une chaine de caracteres avec le nom du plugin
     * tel qu'il apparaitra dans l'administration du site
     *
     */
    function title(){
      return "Minimal";
    }

    /*
     * retourne une chaine de caracteres avec la description du plugin
     * telle qu'elle apparaitra dans l'administration du site
     *
     */
    function description(){
      return "Un plugin 'vide'";
    }

    /*
     * Cette methode sera appelee lors du clic sur le lien "installer"
     * dans l'administration, pour ce plugin.
     * 
     * l'objet $env est fourni en parametre par l'application au moment
     * de l'appel.
     *
     * retourne :
     * - une chaine de caracteres avec un message d'erreur en cas d'erreur
     * - TRUE en cas de succes
     *
     */
    function install($env){
      return true;
    }

    /*
     * Cette methode sera appelee lors du clic sur le lien "desinstaller"
     * dans l'administration, pour ce plugin.
     * 
     * l'objet $env est fourni en parametre par l'application au moment
     * de l'appel.
     *
     * retourne :
     * - une chaine de caracteres avec un message d'erreur en cas d'erreur
     * - TRUE en cas de succes
     *
     */
    function uninstall($env){
      return true;
    }

    /*
     * Cette methode sera appelee lors du clic sur le lien "activer"
     * dans l'administration, pour ce plugin.
     * 
     * l'objet $env est fourni en parametre par l'application au moment
     * de l'appel.
     *
     * retourne :
     * - une chaine de caracteres avec un message d'erreur en cas d'erreur
     * - TRUE en cas de succes
     *
     */
    function enable($env){
      return true;
    }

    /*
     * Cette methode sera appelee lors du clic sur le lien "desctiver"
     * dans l'administration, pour ce plugin.
     * 
     * l'objet $env est fourni en parametre par l'application au moment
     * de l'appel.
     *
     * retourne :
     * - une chaine de caracteres avec un message d'erreur en cas d'erreur
     * - TRUE en cas de succes
     *
     */
    function disable($env){
      return true;
    }

    /*
     * Cette methode sera appelee a chaque requete, avant le traitement
     * de l'action demandee
     * 
     * l'objet $env est fourni en parametre par l'application au moment
     * de l'appel.
     *
     * retourne :
     * - FALSE en cas d'erreur
     * - TRUE en cas de succes
     *
     */
    function init($env){
      return true;
    }

  }

?>